
var bSwitchViews = true;
				
var bStartTableView = true;
				
var currModelId = "ID159427";
							
var currModelVersion = "";
						
var currModelName = "Data - general";
			
var currModelType = "Data";
			 
var currMailAddress = "";
			
var bModInfoWindow = false;
				
var bPrintOne = false;				
				
var bPrintTwo = false;
				
var modInfo = new Array();
		
var overviewimage = new Image();
			
var modelimage68 = new Image();
			
var modelimage45 = new Image();
			
var modelimage90 = new Image();
			
if (!parent.header)
{
	var strPath = top.window.location.href;
	top.location.href= strPath.substring(0, strPath.lastIndexOf("/") + 1) + "../index.html?id=" + currModelId;
}
else
{
	var z = top.header.iZoom;
	checkLoadTableView();
}

function checkLoadTableView()
{
  if (bStartTableView && !parent.header.bModelLoaded)
  {
    top.model.location.href = "../" + currModelId + "/" + currModelId + "t.html"
  }
  else
  {
		overviewimage.src = "../overview/ID159427.png";
			
		if (z == 68) { modelimage68.src = "../images/ado16.png"; }
		else { window.setTimeout("eval(\"modelimage68.src = '../images/ado16.png'\");", 1000); }
			
		if (z == 45) { modelimage45.src = "../images/ado17.png"; }
		else { window.setTimeout("eval(\"modelimage45.src = '../images/ado17.png'\");", 1000); }
			
		if (z == 90) { modelimage90.src = "../images/ado18.png"; }
		else { window.setTimeout("eval(\"modelimage90.src = '../images/ado18.png'\");", 1000); }
			
	}
	parent.header.bModelLoaded = true;
}

function actualizeImageArea()
{
	prepareImageMap();
		
	createImageArea(9.5, 1.2, 12.5, 2.8, "ID172348", "ID159427", "ID172348", "", false);
					
	createImageArea(14, 35.7, 17, 37.3, "ID168970", "ID159427", "ID168970", "", false);
					
	createImageArea(9.5, 20.2, 12.5, 21.8, "ID168267", "ID159427", "ID168267", "", false);
					
	createImageArea(1.5, 38.2, 4.5, 39.8, "ID159558", "ID159427", "ID159558", "", false);
					
	createImageArea(14, 29.2, 17, 30.8, "ID159555", "ID159427", "ID159555", "", false);
					
	createImageArea(5.5, 35.7, 8.5, 37.3, "ID159552", "ID159427", "ID159552", "", false);
					
	createImageArea(1.5, 35.7, 4.5, 37.3, "ID159549", "ID159427", "ID159549", "", false);
					
	createImageArea(9.5, 32.2, 12.5, 33.8, "ID159546", "ID159427", "ID159546", "", false);
					
	createImageArea(5.5, 32.2, 8.5, 33.8, "ID159543", "ID159427", "ID159543", "", false);
					
	createImageArea(1.5, 32.2, 4.5, 33.8, "ID159540", "ID159427", "ID159540", "", false);
					
	createImageArea(18.5, 32.2, 21.5, 33.8, "ID159537", "ID159427", "ID159537", "", false);
					
	createImageArea(9.5, 35.7, 12.5, 37.3, "ID159534", "ID159427", "ID159534", "", false);
					
	createImageArea(5.5, 38.2, 8.5, 39.8, "ID159531", "ID159427", "ID159531", "", false);
					
	createImageArea(18.5, 29.2, 21.5, 30.8, "ID159528", "ID159427", "ID159528", "", false);
					
	createImageArea(13.5, 4.7, 16.5, 6.3, "ID159525", "ID159427", "ID159525", "", false);
					
	createImageArea(21.5, 4.7, 24.5, 6.3, "ID159522", "ID159427", "ID159522", "", false);
					
	createImageArea(9.5, 4.7, 12.5, 6.3, "ID159519", "ID159427", "ID159519", "", false);
					
	createImageArea(17.5, 4.7, 20.5, 6.3, "ID159516", "ID159427", "ID159516", "", false);
					
	createImageArea(5.5, 4.7, 8.5, 6.3, "ID159513", "ID159427", "ID159513", "", false);
					
	createImageArea(14, 32.2, 17, 33.8, "ID159510", "ID159427", "ID159510", "", false);
					
	createImageArea(5.5, 29.2, 8.5, 30.8, "ID159507", "ID159427", "ID159507", "", false);
					
	createImageArea(1.5, 29.2, 4.5, 30.8, "ID159504", "ID159427", "ID159504", "", false);
					
	createImageArea(9.5, 29.2, 12.5, 30.8, "ID159501", "ID159427", "ID159501", "", false);
					
	createImageArea(9.5, 13.2, 12.5, 14.8, "ID159498", "ID159427", "ID159498", "", false);
					
	createImageArea(25.5, 4.7, 28.5, 6.3, "ID159495", "ID159427", "ID159495", "", false);
					
	createImageArea(9.5, 38.2, 12.5, 39.8, "ID159492", "ID159427", "ID159492", "", false);
					
	createImageArea(13.5, 7.7, 16.5, 9.3, "ID159489", "ID159427", "ID159489", "", false);
					
	createImageArea(1.5, 20.2, 4.5, 21.8, "ID159486", "ID159427", "ID159486", "", false);
					
	createImageArea(5.5, 15.7, 8.5, 17.3, "ID159483", "ID159427", "ID159483", "", false);
					
	createImageArea(14, 38.2, 17, 39.8, "ID159480", "ID159427", "ID159480", "", false);
					
	createImageArea(9.5, 10.2, 12.5, 11.8, "ID159477", "ID159427", "ID159477", "", false);
					
	createImageArea(1.5, 15.7, 4.5, 17.3, "ID159474", "ID159427", "ID159474", "", false);
					
	createImageArea(13.5, 10.2, 16.5, 11.8, "ID159471", "ID159427", "ID159471", "", false);
					
	createImageArea(9.5, 7.7, 12.5, 9.3, "ID159468", "ID159427", "ID159468", "", false);
					
	createImageArea(5.5, 1.2, 8.5, 2.8, "ID159465", "ID159427", "ID159465", "", false);
					
	createImageArea(1.5, 10.2, 4.5, 11.8, "ID159462", "ID159427", "ID159462", "", false);
					
	createImageArea(5.5, 10.2, 8.5, 11.8, "ID159459", "ID159427", "ID159459", "", false);
					
	createImageArea(5.5, 20.2, 8.5, 21.8, "ID159456", "ID159427", "ID159456", "", false);
					
	createImageArea(5.5, 25.7, 8.5, 27.3, "ID159453", "ID159427", "ID159453", "", false);
					
	createImageArea(1.5, 25.7, 4.5, 27.3, "ID159450", "ID159427", "ID159450", "", false);
					
	createImageArea(1.5, 7.7, 4.5, 9.3, "ID159447", "ID159427", "ID159447", "", false);
					
	createImageArea(1.5, 4.7, 4.5, 6.3, "ID159444", "ID159427", "ID159444", "", false);
					
	createImageArea(5.5, 7.7, 8.5, 9.3, "ID159441", "ID159427", "ID159441", "", false);
					
	createImageArea(5.5, 13.2, 8.5, 14.8, "ID159438", "ID159427", "ID159438", "", false);
					
	createImageArea(1.5, 13.2, 4.5, 14.8, "ID159435", "ID159427", "ID159435", "", false);
					
	createImageArea(9.5, 25.7, 12.5, 27.3, "ID159432", "ID159427", "ID159432", "", false);
					
	createImageArea(1.5, 1.2, 4.5, 2.8, "ID159429", "ID159427", "ID159429", "", false);
					
	imageMapsReady();
}
			
			ID159429D='<span class=\\\"mov_name\\\">Legal framework regulations</span>';				
				ID159432D='<span class=\\\"mov_name\\\">Gap report</span>';				
				ID159435D='<span class=\\\"mov_name\\\">Process documentation</span>';				
				ID159438D='<span class=\\\"mov_name\\\">Organisational structure</span>';				
				ID159441D='<span class=\\\"mov_name\\\">List of affected areas</span>';				
				ID159444D='<span class=\\\"mov_name\\\">Management decision</span>';				
				ID159447D='<span class=\\\"mov_name\\\">Projects plans</span>';				
				ID159450D='<span class=\\\"mov_name\\\">AS-IS analysis</span>';				
				ID159453D='<span class=\\\"mov_name\\\">TO-BE model</span>';				
				ID159456D='<span class=\\\"mov_name\\\">Requirements on IT</span>';				
				ID159459D='<span class=\\\"mov_name\\\">Projects list</span>';				
				ID159462D='<span class=\\\"mov_name\\\">Projects schedule</span>';				
				ID159465D='<span class=\\\"mov_name\\\">Local framework adaptations</span>';				
				ID159468D='<span class=\\\"mov_name\\\">Implementation scenarios</span>';				
				ID159471D='<span class=\\\"mov_name\\\">Business case</span>';				
				ID159474D='<span class=\\\"mov_name\\\">Requirements on processes</span>';				
				ID159477D='<span class=\\\"mov_name\\\">Implementation plan</span>';				
				ID159480D='<span class=\\\"mov_name\\\">Loss collection DB</span>';				
				ID159483D='<span class=\\\"mov_name\\\">Requirements on organisational structure</span>';				
				ID159486D='<span class=\\\"mov_name\\\">IT service documentation</span>';				
				ID159489D='<span class=\\\"mov_name\\\">Unplanned changes</span>';				
				ID159492D='<span class=\\\"mov_name\\\">Disclosure reports</span>';				
				ID159495D='<span class=\\\"mov_name\\\">Code of conduct</span>';				
				ID159498D='<span class=\\\"mov_name\\\">Staff regulations</span>';				
				ID159501D='<span class=\\\"mov_name\\\">Control documentation</span>';				
				ID159504D='<span class=\\\"mov_name\\\">Risk catalogue</span>';				
				ID159507D='<span class=\\\"mov_name\\\">IT risks catalogue</span>';				
				ID159510D='<span class=\\\"mov_name\\\">List of critical activities</span>';				
				ID159513D='<span class=\\\"mov_name\\\">Risk strategy</span>';				
				ID159516D='<span class=\\\"mov_name\\\">Policy statement</span>';				
				ID159519D='<span class=\\\"mov_name\\\">Company strategy</span>';				
				ID159522D='<span class=\\\"mov_name\\\">Entity objectives</span>';				
				ID159525D='<span class=\\\"mov_name\\\">Critical success factors</span>';				
				ID159528D='<span class=\\\"mov_name\\\">Potential events</span>';				
				ID159531D='<span class=\\\"mov_name\\\">Monitoring info</span>';				
				ID159534D='<span class=\\\"mov_name\\\">Audit results</span>';				
				ID159537D='<span class=\\\"mov_name\\\">Deficiencies</span>';				
				ID159540D='<span class=\\\"mov_name\\\">Action plan</span>';				
				ID159543D='<span class=\\\"mov_name\\\">Control activities</span>';				
				ID159546D='<span class=\\\"mov_name\\\">Monitoring plan</span>';				
				ID159549D='<span class=\\\"mov_name\\\">Audit readiness</span>';				
				ID159552D='<span class=\\\"mov_name\\\">Certificate</span>';				
				ID159555D='<span class=\\\"mov_name\\\">Communication strategy</span>';				
				ID159558D='<span class=\\\"mov_name\\\">ICS report</span>';				
				ID168267D='<span class=\\\"mov_name\\\">IT service imp. scenarios</span>';				
				ID168970D='<span class=\\\"mov_name\\\">Actionable information</span>';				
				ID172348D='<span class=\\\"mov_name\\\">Framework best practices</span>';				
				
			
function readCM()
{
			ID159429CM = new instCM("Legal framework regulations");
ID159432CM = new instCM("Gap report");
ID159435CM = new instCM("Process documentation");
ID159438CM = new instCM("Organisational structure");
ID159441CM = new instCM("List of affected areas");
ID159444CM = new instCM("Management decision");
ID159447CM = new instCM("Projects plans");
ID159450CM = new instCM("AS-IS analysis");
ID159453CM = new instCM("TO-BE model");
ID159456CM = new instCM("Requirements on IT");
ID159459CM = new instCM("Projects list");
ID159462CM = new instCM("Projects schedule");
ID159465CM = new instCM("Local framework adaptations");
ID159468CM = new instCM("Implementation scenarios");
ID159471CM = new instCM("Business case");
ID159474CM = new instCM("Requirements on processes");
ID159477CM = new instCM("Implementation plan");
ID159480CM = new instCM("Loss collection DB");
ID159483CM = new instCM("Requirements on organisational structure");
ID159486CM = new instCM("IT service documentation");
ID159489CM = new instCM("Unplanned changes");
ID159492CM = new instCM("Disclosure reports");
ID159495CM = new instCM("Code of conduct");
ID159498CM = new instCM("Staff regulations");
ID159501CM = new instCM("Control documentation");
ID159504CM = new instCM("Risk catalogue");
ID159507CM = new instCM("IT risks catalogue");
ID159510CM = new instCM("List of critical activities");
ID159513CM = new instCM("Risk strategy");
ID159516CM = new instCM("Policy statement");
ID159519CM = new instCM("Company strategy");
ID159522CM = new instCM("Entity objectives");
ID159525CM = new instCM("Critical success factors");
ID159528CM = new instCM("Potential events");
ID159531CM = new instCM("Monitoring info");
ID159534CM = new instCM("Audit results");
ID159537CM = new instCM("Deficiencies");
ID159540CM = new instCM("Action plan");
ID159543CM = new instCM("Control activities");
ID159546CM = new instCM("Monitoring plan");
ID159549CM = new instCM("Audit readiness");
ID159552CM = new instCM("Certificate");
ID159555CM = new instCM("Communication strategy");
ID159558CM = new instCM("ICS report");
ID168267CM = new instCM("IT service imp. scenarios");
ID168970CM = new instCM("Actionable information");
ID172348CM = new instCM("Framework best practices");
}
		